pub fn apply_agent_surface(
command: &mut Command,
spec: &ToolSpec,
ctx: &AgentModeContext,
)Expand description
Apply the visible agent surface to a clap command tree.
pub fn apply_agent_surface(
command: &mut Command,
spec: &ToolSpec,
ctx: &AgentModeContext,
)Apply the visible agent surface to a clap command tree.