pub fn render_agent_help(spec: &ToolSpec, ctx: &AgentModeContext) -> StringExpand description
Render the visible agent capability surface as structured text.
pub fn render_agent_help(spec: &ToolSpec, ctx: &AgentModeContext) -> StringRender the visible agent capability surface as structured text.