Shared CLI application metadata.
Structs
- Tool
Spec - Shared metadata for a CLI binary.
Enums
- Contract
Error - Errors raised when validating a tool’s adoption of the shared CLI contract.
- Tool
Contract - Declares whether a tool has opted into the authoritative shared CLI contract.
Constants
- WORKSPACE_
REPO - Default repository metadata for binaries that ship from the shared tools workspace.
Functions
- workspace_
tool - Create a
ToolSpecfor a binary shipped from the shared tools workspace.