Shared binary entrypoint helpers for workspace CLI tools.
Functions
- run_
cli_ from - Parse CLI arguments from a caller-provided argv, route shared metadata commands, and run the domain handler.
- run_
cli_ no_ doctor_ from - Parse caller-provided argv, route shared metadata commands, and run the domain handler for a tool without doctor support.