pub fn print_error(command: &str, output: JsonOutput, message: &str) -> i32Expand description
Print a standard error response and return a failing exit code.
pub fn print_error(command: &str, output: JsonOutput, message: &str) -> i32Print a standard error response and return a failing exit code.