Module runner

Module runner 

Shared CLI runner helpers.

Structs

FatalCliError
Shared fatal CLI error state.

Functions

parse_and_exit
Parse CLI state, run the handler, and exit the process with the resulting code.
parse_and_run
Parse CLI state with one closure and execute it with another.
run_with_display_error_handler
Run a fallible CLI closure with shared fatal rendering for any displayable error type.
run_with_fatal_handler
Run a fallible CLI closure and convert shared fatal errors into exit codes.