FatalCliError

Struct FatalCliError 

pub struct FatalCliError { /* private fields */ }
Shared fatal CLI error state.

Implementations

Source

impl FatalCliError

pub fn new( command: impl Into<String>, output: JsonOutput, message: impl Into<String>, ) -> Self

Create a fatal CLI error with the shared renderer contract.

pub fn command(&self) -> &str

Return the command label used in shared error output.

pub const fn output(&self) -> JsonOutput

Return the output mode used for shared error rendering.

pub fn message(&self) -> &str

Return the fatal message.

pub fn render(&self) -> String

Render the fatal error as a string without emitting it.

pub fn emit(&self)

Emit the fatal error to the correct output stream.

pub fn emit_and_exit_code(self) -> i32

Emit the fatal error and return the shared failure exit code.