Shared CLI application metadata.
Structs
- Tool
Spec - Shared metadata for a CLI binary.
Constants
- WORKSPACE_
REPO - Default repository metadata for binaries that ship from the shared tools workspace.
Functions
- workspace_
tool - Create a
ToolSpecfor a binary shipped from the shared tools workspace.