Module app

Module app 

Shared CLI application metadata.

Structs

ToolSpec
Shared metadata for a CLI binary.

Constants

WORKSPACE_REPO
Default repository metadata for binaries that ship from the shared tools workspace.

Functions

workspace_tool
Create a ToolSpec for a binary shipped from the shared tools workspace.