Module binary

Module binary 

Shared binary entrypoint helpers for workspace CLI tools.

Functions

run_cli_from
Parse CLI arguments from a caller-provided argv, route shared metadata commands, and run the domain handler.
run_cli_no_doctor_from
Parse caller-provided argv, route shared metadata commands, and run the domain handler for a tool without doctor support.