Shared standard CLI commands.
Structs
- NoDoctor
- Shared doctorless adapter for tools that do not expose a doctor command.
Enums
- Standard
Command - Shared metadata commands exposed by workspace binaries.
Traits
- Standard
Command Map - Map crate-local metadata commands onto the shared
StandardCommandsurface.
Functions
- map_
standard_ command - Convert a crate-local metadata command into a shared
StandardCommand. - maybe_
run_ standard_ command - Run a mapped standard command when a tool exposes one.
- maybe_
run_ standard_ command_ no_ doctor - Run a mapped standard command for a tool with no doctor support.
- parse_
command_ ref_ with_ agent_ surface_ from - Parse argv and hand the typed CLI to a borrowed callback when parsing succeeds.
- parse_
command_ with_ agent_ surface - Parse a clap CLI against the current normal or agent-filtered surface.
- parse_
command_ with_ agent_ surface_ from - Parse argv against the current normal or agent-filtered surface.
- run_
standard_ command - Execute a shared standard command.
- run_
standard_ command_ no_ doctor - Execute a shared standard command for a tool with no doctor support.