Shared CLI runner helpers.
Structs
- Fatal
CliError - Shared fatal CLI error state.
Functions
- parse_
and_ exit - Parse CLI state, run the handler, and exit the process with the resulting code.
- parse_
and_ run - Parse CLI state with one closure and execute it with another.
- run_
with_ display_ error_ handler - Run a fallible CLI closure with shared fatal rendering for any displayable error type.
- run_
with_ fatal_ handler - Run a fallible CLI closure and convert shared fatal errors into exit codes.