pub struct FatalCliError { /* private fields */ }Expand description
Shared fatal CLI error state.
Implementations
Sourceimpl FatalCliError
impl FatalCliError
Sourcepub fn new(
command: impl Into<String>,
output: JsonOutput,
message: impl Into<String>,
) -> Self
pub fn new( command: impl Into<String>, output: JsonOutput, message: impl Into<String>, ) -> Self
Create a fatal CLI error with the shared renderer contract.
Sourcepub const fn output(&self) -> JsonOutput
pub const fn output(&self) -> JsonOutput
Return the output mode used for shared error rendering.
Sourcepub fn emit_and_exit_code(self) -> i32
pub fn emit_and_exit_code(self) -> i32
Emit the fatal error and return the shared failure exit code.